package de.itstall;

class World {
	private GameField field;
	private Player player;
	private int lineBreaks = 0;
	private boolean tempLineBreaks = false;

	World() {
		String canvas = "#########      ##      ####    ##      #########";
		this.field = new GameField(8, canvas);
		this.player = new Player(new Position(1, 1));
	}

	String draw() {
		StringBuilder sb = new StringBuilder();
		String s = this.player.draw(this.field.toString(), this.field.width);

		int breaks = this.lineBreaks;

		if(tempLineBreaks) {
			breaks--;
		}

		sb.append("\n".repeat(Math.max(0, breaks)));

		for (int y = 0; y < this.field.height; y++) {
			sb.append(s.substring(y * this.field.width, (y + 1) * this.field.width));
			sb.append("\n");
		}

		return sb.toString();
	}

	void keyPressed(String s) {
		if( s.isEmpty() ) {
			return;
		}

		int x = this.player.pos.getX();
		int y = this.player.pos.getY();

		switch(s.charAt(0)) {
			case 'a':
				x--;
				break;
			case 'd':
				x++;
				break;
			case 'w':
				y--;
				break;
			case 's':
				y++;
				break;
			case 'q':
				System.exit(0);
			default:
				System.out.println("Key not found");
				break;

		}
		if(this.field.checkField(x, y)) {
			this.player.pos.setPosition(x, y);
			System.out.println(this.draw());
		} else {
			this.tempLineBreaks = true;
			System.out.println(this.draw());
			System.out.println("Move not possible");
		}
	}

	void setLineBreaks(int lineBreaks) {
		this.lineBreaks = lineBreaks;
	}
}
